@@ -1,4 +1,4 @@
-use 5.008008;
+use 5.008001;
 use strict;
 use warnings;
 
@@ -8,7 +8,7 @@ use Scalar::Util ();
 package Hydrogen;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010';
+our $VERSION   = '0.011';
 
 use Exporter::Shiny qw( croak fc );
 
@@ -34,6 +34,15 @@ else {
    eval 'sub fc { lc( @_ ? $_[0] : $_ ) }';
 }
 
+# Compatibility shim for Perl < 5.10
+eval 'require re';
+unless ( exists &re::is_regexp ) {
+    require B;
+    *re::is_regexp = sub {
+        eval { B::svref_2object( $_[0] )->MAGIC->TYPE eq 'r' };
+    };
+}
+
 1;
 
 __END__
@@ -262,6 +271,22 @@ otherwise.
 
 If no C<< $string >> is provided, operates on C<< $_ >>.
 
+=head1 DEPENDENCIES
+
+Hydrogen requires Perl 5.8.1 or above.
+
+Hydrogen requires the modules L<Carp>, L<Data::Dumper>, L<List::Util>, and
+L<Scalar::Util>, all of which normally come with Perl. Hydrogen needs at least
+version 1.54 of List::Util; Perl versions older than 5.32.0 will be distributed
+with older versions of List::Util, but upgrades to the module can be found on
+the CPAN.
+
+Hydrogen also requires the module L<Exporter::Shiny> which can be found on
+the CPAN.
+
+Hydrogen's test suite requires the module L<Test2::V0> which can be found on
+the CPAN.
+
 =head1 BUGS
 
 Please report any bugs to
